@@ -13,8 +13,8 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along with
- *  this program; if not, write to the Free Software Foundation, Inc., 675 Mass
- *  Ave, Cambridge, MA 02139, USA.
+ *  this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
  *
  */
 
@@ -37,8 +37,10 @@ typedef enum nwipe_log_t_
 void nwipe_log( nwipe_log_t level, const char* format, ... );
 void nwipe_perror( int nwipe_errno, const char* f, const char* s );
 
-/* Stops ncurses being updated whilst we are writing log to STDOUT */
-extern int log_writing_screen;
+/* Global array to hold log values to print when logging to STDOUT */
+//extern char **log_lines;
+//extern int log_current_element;    
+//extern int log_elements_allocated;
 
 #endif /* LOGGING_H_ */
 
