@@ -48,18 +48,9 @@ int main( int argc, char** argv )
         int nwipe_enumerated;          /* The number of contexts that have been enumerated. */
         int nwipe_error = 0;           /* An error counter.                                 */
         int nwipe_selected = 0;        /* The number of contexts that have been selected.   */
-        int nwipe_shmid;               /* A shared memory handle for the context array.     */
-        int nwipe_wait  = 0;           /* The number of child processes that have returned. */
         pthread_t nwipe_gui_thread;    /* The thread ID of the GUI thread.                  */
         pthread_t nwipe_sigint_thread; /* The thread ID of the sigint handler.              */
 
-        /* The list of device filenames. */
-        char** nwipe_names = NULL;
-        
-        /* Used to write-out the result file. */
-        char nwipe_result_file [FILENAME_MAX];
-        FILE* nwipe_result_fp;
-
         /* The entropy source file handle. */
         int nwipe_entropy; 
 
@@ -78,6 +69,9 @@ int main( int argc, char** argv )
         /* Initialised and populated in device scan.     */
         nwipe_context_t **c1 = 0;
 
+        /* The array of pointers to contexts that will actually be wiped. */
+        nwipe_context_t **c2 = (nwipe_context_t **)malloc(nwipe_enumerated * sizeof(nwipe_context_t *));
+
         /* Parse command line options. */
         nwipe_optind = nwipe_options_parse( argc, argv );
 
@@ -102,10 +96,15 @@ int main( int argc, char** argv )
         else
         {
 
-                 argv += nwipe_optind;
+                argv += nwipe_optind;
                 argc -= nwipe_optind;
 
                 nwipe_enumerated = nwipe_device_get( &c1, argv, argc );
+                if ( nwipe_enumerated == 0 )
+                {
+                    exit(1);
+                }
+
         }
 
 
@@ -130,6 +129,7 @@ int main( int argc, char** argv )
         sigaddset(&sigset, SIGTERM);
         sigaddset(&sigset, SIGQUIT);
         sigaddset(&sigset, SIGINT);
+        sigaddset(&sigset, SIGUSR1);
         pthread_sigmask(SIG_SETMASK, &sigset, NULL);
   
         /* Create a signal handler thread.  This thread will catch all           */
@@ -141,7 +141,7 @@ int main( int argc, char** argv )
         nwipe_misc_thread_data_t nwipe_misc_thread_data;
         nwipe_thread_data_ptr_t nwipe_thread_data_ptr;
         
-        nwipe_thread_data_ptr.c = c1;
+        nwipe_thread_data_ptr.c = c2;
         nwipe_misc_thread_data.nwipe_enumerated = nwipe_enumerated;
         if( !nwipe_options.nogui )
                 nwipe_misc_thread_data.gui_thread = &nwipe_gui_thread;
@@ -225,9 +225,6 @@ int main( int argc, char** argv )
         /* Pass the number selected to the struct for other threads */
         nwipe_misc_thread_data.nwipe_selected = nwipe_selected;
 
-        /* The array of pointers to contexts that will actually be wiped. */
-        nwipe_context_t **c2 = (nwipe_context_t **)malloc(nwipe_enumerated * sizeof(nwipe_context_t *));
-
         /* Populate the array of selected contexts. */
         for( i = 0, j = 0 ; i < nwipe_enumerated ; i++ )
         {
@@ -287,10 +284,8 @@ int main( int argc, char** argv )
                 }
                 */
 
-                /* Attempt to get serial number of device. */
-
-                ioctl(c2[i]->device_fd, HDIO_GET_IDENTITY, &c2[i]->identity);
-                if ( c2[i]->identity.serial_no ) {
+                /* Print serial number of device if it exists. */
+                if ( strlen(c2[i]->identity.serial_no) ) {
                         nwipe_log( NWIPE_LOG_INFO, "Device %s has serial number %s", c2[i]->device_name, c2[i]->identity.serial_no);
                 }
                 
@@ -496,6 +491,7 @@ void *signal_hand(void *ptr)
         sigaddset(&sigset, SIGTERM);
         sigaddset(&sigset, SIGQUIT);
         sigaddset(&sigset, SIGINT);
+        sigaddset(&sigset, SIGUSR1);
 
         int i;        
 
@@ -517,13 +513,60 @@ void *signal_hand(void *ptr)
 
                 switch ( sig ) {
 
+                        // Log current status. All values are automatically updated by the GUI
+                        case SIGUSR1 :
+                        {
+                                compute_stats(ptr);
+
+                                for( i = 0; i < nwipe_misc_thread_data->nwipe_selected; i++ )
+                                {
+
+                                        if ( c[i]->thread )
+                                        {
+                                                char *status;
+                                                switch( c[i]->pass_type )
+                                                {
+                                                        case NWIPE_PASS_FINAL_BLANK:
+                                                                status = "[blanking]";
+                                                                break;
+
+                                                        case NWIPE_PASS_FINAL_OPS2:
+                                                                status = "[OPS-II final]";
+                                                                break;
+
+                                                        case NWIPE_PASS_WRITE:
+                                                                status = "[writing]";
+                                                                break;
+
+                                                        case NWIPE_PASS_VERIFY:
+                                                                status = "[verifying]";
+                                                                break;
+
+                                                        case NWIPE_PASS_NONE:
+                                                                break;
+                                                }
+                                                if( c[i]->sync_status ) { status = "[syncing]"; }
+                                                nwipe_log( NWIPE_LOG_INFO, "%s: %05.2f%%, round %i of %i, pass %i of %i %s", \
+                                                     c[i]->device_name, c[i]->round_percent, c[i]->round_working, c[i]->round_count, c[i]->pass_working, c[i]->pass_count, status );
+                                        }
+                                        else
+                                        {
+                                                if( c[i]->result == 0 ) { nwipe_log( NWIPE_LOG_INFO, "%s: Success", c[i]->device_name ); }
+                                                else if( c[i]->signal ) { nwipe_log( NWIPE_LOG_INFO, "%s: Failure: signal %i", c[i]->device_name, c[i]->signal ); }
+                                                else                    { nwipe_log( NWIPE_LOG_INFO, "%s: Failure: code %i", c[i]->device_name, c[i]->result ); }
+                                        }
+                                }
+
+                                break;
+                        }
+                        
                         case SIGHUP  :
                         case SIGINT  :
                         case SIGQUIT :
                         case SIGTERM :
                         {
 
-                                for( i = 0; i < nwipe_misc_thread_data->nwipe_enumerated; i++ )
+                                for( i = 0; i < nwipe_misc_thread_data->nwipe_selected; i++ )
                                 {
 
                                         if ( c[i]->thread )
@@ -551,7 +594,6 @@ void *signal_hand(void *ptr)
                                         printf("%s\n", log_lines[i]);
                                 }
 
-
                                 printf("Program interrupted (caught signal %d)\n", sig); 
 
                                 // Cleanup
